pub struct CountRange<T> { /* private fields */ }Expand description
Inclusive count range with optional upper bound.
Implementations
Sourceimpl<T: Copy + Ord> CountRange<T>
impl<T: Copy + Ord> CountRange<T>
Sourcepub const fn unbounded_from(min: T) -> Self
pub const fn unbounded_from(min: T) -> Self
Return an inclusive range with no upper bound.
Sourcepub fn new(min: T, max: Option<T>) -> Option<Self>
pub fn new(min: T, max: Option<T>) -> Option<Self>
Build a validated inclusive range.
Returns None when max is present and min > max.
Sourcepub fn contains_range(self, sub: Self) -> bool
pub fn contains_range(self, sub: Self) -> bool
Return true when sub is wholly contained by this range.