pub struct IntegerBounds { /* private fields */ }Expand description
A canonical closed interval over signed 64-bit integers.
JSON Schema’s exclusive integer bounds are normalized to inclusive endpoints at parse time, so semantically identical intervals have one representation.
Implementations
Sourceimpl IntegerBounds
impl IntegerBounds
Sourcepub fn new(lower: Option<i64>, upper: Option<i64>) -> Option<Self>
pub fn new(lower: Option<i64>, upper: Option<i64>) -> Option<Self>
Build a validated closed integer interval.
Returns None when both endpoints are present and lower > upper.
Sourcepub fn contains_i64(self, value: i64) -> bool
pub fn contains_i64(self, value: i64) -> bool
Return true when value is inside this interval.
Sourcepub fn contains_i128(self, value: i128) -> bool
pub fn contains_i128(self, value: i128) -> bool
Return true when value is inside this interval.
Sourcepub fn contains_bounds(self, sub: Self) -> bool
pub fn contains_bounds(self, sub: Self) -> bool
Return true when sub is wholly contained by this interval.
Sourcepub fn as_number_bounds(self) -> NumberBounds
pub fn as_number_bounds(self) -> NumberBounds
Project this integer interval into the corresponding number interval.